\ProvidesClass{JournalTitle}[40000]
\NeedsTeXFormat{LaTeX2e}

\LoadClass{book}

\RequirePackage{color}
\RequirePackage{lettrine}
\RequirePackage{fontspec}
\RequirePackage{multicol}
\RequirePackage{fancyhdr}
\RequirePackage{geometry}
\RequirePackage{tikz}
\RequirePackage{titlesec}
\RequirePackage{caption}
\RequirePackage{booktabs}
\RequirePackage{indentfirst}

% 页边距、页眉页脚相关信息
\geometry{left=2.1cm,right=2.1cm,top=1.2cm,bottom=2.85cm}
\setlength{\voffset}{-15mm}
\setlength{\topmargin}{0mm}
\setlength{\headheight}{10mm}
\setlength{\headsep}{0mm}
\setlength{\footskip}{5mm}

% 字体类型
\setmainfont{Minion Pro}
\setsansfont{Arial}
\setmonofont{Arial Bold}

% 双栏之间的距离
\setlength\columnsep{20pt}

% 首行缩进
\setlength{\parindent}{2em}

% 字母换行
\hyphenpenalty=5000
\tolerance=1000

% 期刊的青色定义
\definecolor{indego}{RGB}{46,100,210}

% 页眉页脚类型
\pagestyle{fancy}

% 页脚中的卷号、日期
\newcommand{\volume}[1]{\def\@volume{#1}}
\renewcommand{\date}[1]{\def\@date{#1}}
\newcommand{\page}[1]{\def\@page{#1}}

% 表格图片引用
\newcommand{\refpic}[1]{{\color{indego}Fig. \ref{#1}}}
\newcommand{\reftab}[1]{{\color{indego}Table \ref{#1}}}

% 强制不换页
\renewcommand{\cleardoublepage}{}
\renewcommand{\clearpage}{}

% 引用角标、颜色
\def\@cite#1#2{\textsuperscript{[{\color{indego}{#1\if@tempswa , #2\fi}}]}}

% 页眉设置，使用TikZ画蓝框，老麻烦了
\fancyhead[O]{\begin{tikzpicture}
		\draw[fill=indego,draw=white] (0,0) rectangle (\linewidth,0.8);
		\node[anchor=west,text height=1.5ex, text depth=.25ex](L)at(0,0.4)
		{\color{white}\fontsize{9pt}{0pt}\texttt{\@titleshort}};
		\node[anchor=east,text height=1.5ex, text depth=.25ex](R)at(\linewidth,0.4)
		{\color{white}\fontsize{10pt}{0pt}\texttt{\quad }};
	\end{tikzpicture}}		

\fancyhead[E]{\begin{tikzpicture}
		\draw[fill=indego,draw=white] (0,0) rectangle (\linewidth,0.8);
		\node[anchor=west,text height=1.5ex, text depth=.25ex](L)at(0,0.4)
		{\color{white}\fontsize{10pt}{0pt}\texttt{\quad }};
		\node[anchor=east,text height=1.5ex, text depth=.25ex](R)at(\linewidth,0.4)
		{\color{white}\fontsize{9pt}{0pt}\texttt{\@titleshort}};
	\end{tikzpicture}}
	
% 页脚设置
\fancyfoot[RE,LO]{\fontsize{8pt}{0pt}\color{indego}\textsf
	{International Journal of Crowd Science | VOL \@volume | \@date | \@page}}
\fancyfoot[LE,RO]{\fontsize{8pt}{0pt}\color{indego}\textsf
	\thepage}
\fancyfoot[C]{}

%把页眉线的宽度设为零，即去掉页眉线
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}

% 插入图片、表格的bug
\newenvironment{figurehere}
{\def\@captype{figure}}
{}
\newenvironment{tabhere}
{\def\@captype{table}}
{}

% 修改原先图片编号Figure. 1为Fig. 1
\renewcommand{\figurename}{Fig.}

% 首页脚注调整
\renewcommand\@makefntext[1]{
	\noindent\makebox[.02\columnwidth][l]{\@thefnmark}%
	\parbox[t]{1.42\columnwidth}{#1}}

% 短标题、摘要、关键词、DOI、首段首字母定义
\newcommand{\titleshort}[1]{\def\@titleshort{#1}}
\newcommand{\abstract}[1]{\def\@abstract{#1}}
\newcommand{\keywords}[1]{\def\@keywords{#1}}
\newcommand{\doi}[1]{\def\@doi{#1}}
\newcommand{\firstletter}[1]{\lettrine[lines=3]{\color{indego}#1}{}}

% 章节标题
\renewcommand\thesection {\arabic {section}}
\titleformat{\section}{\bfseries\fontsize{12pt}{13.5pt}\selectfont\color{indego}}{\thesection}{1em}{}
\titleformat{\subsection}{\bfseries\fontsize{10pt}{0pt}\selectfont\color{indego}}{\thesubsection}{1em}{}

% 修改引用格式
\renewenvironment{thebibliography}[1]
{\section*{\bibname
		\@mkboth{\bibname}{\bibname}}%
	\list{\@biblabel{\@arabic\c@enumiv}}%
	{\settowidth\labelwidth{\@biblabel{#1}}%
		\leftmargin\labelwidth
		\advance\leftmargin\labelsep
		\@openbib@code
		\usecounter{enumiv}%
		\let\p@enumiv\@empty
		\renewcommand\theenumiv{\@arabic\c@enumiv}}%
	\sloppy\clubpenalty4000\widowpenalty4000%
	\sfcode`\.\@m}
{\def\@noitemerr
	{\@latex@warning{Empty `thebibliography' environment}}%
	\endlist}

\renewcommand{\bibname}{\color{indego}References}

% 标题、作者、摘要、关键词
\renewcommand\maketitle{
	
	\let\footnotesize\small
	\let\footnoterule\relax
	\let\footnote\thanks
	%\null\vfil
	\thispagestyle{empty}
	\noindent\fcolorbox{indego}{indego}
	{
		\parbox{0.98\linewidth}
		{
			\vskip 0em%
			\color{white}
			\fontsize{10pt}{0pt}\texttt{\mbox{\quad} }
			\par
			\vskip -0.35em%
			\fontsize{8pt}{0pt}\texttt \@doi  \hfill \fontsize{10pt}{0pt}{\texttt{International Journal of Crowd Science}}\\[-3.5mm]

			\par
		}
	}
		
	\vskip 3em%

	\noindent{\fontsize{18pt}{23pt}\selectfont\color{indego}\textbf\@title\par}%
	\vskip 1.5em%
	\noindent{\fontsize{10pt}{0pt}\lineskip.75em \textsf\@author\par}%
	\vskip 1.5em%
	
	\noindent\rule{\textwidth}{0.1pt}
	\noindent{\fontsize{11pt}{0pt} \color{indego}\textbf{ABSTRACT} \par}%
	\noindent{\fontsize{8.5pt}{11pt}\selectfont\textsf\@abstract \par}
	\vskip 1em%
	\noindent{\fontsize{11pt}{0pt}\color{indego}\textbf{KEYWORDS} \par}%
	\noindent{\fontsize{9pt}{0pt}\textsf\@keywords \par}
	\noindent\rule{\textwidth}{0.1pt}
	
	\vfil\null
	\setcounter{footnote}{0}%
	\global\let\thanks\relax
	\global\let\maketitle\relax
	\global\let\@thanks\@empty
	\global\let\@author\@empty
	\global\let\@title\@empty
	\global\let\@abstract\@empty
	\global\let\@keywords\@empty
	\global\let\title\relax
	\global\let\author\relax
	\global\let\and\relax
	\global\let\abstract\relax
	\global\let\keywords\relax
	
	\fontsize{9.5pt}{11.1pt}\selectfont
}
